@@ -102,37 +102,59 @@ public class TVModelLoader2 implements ProgressTrackable {
 	/**
 	* Length in bytes of the input stream, or -1 if not known.
 	*/
-	public void setLength(int length) {
-		loadProgress.setLength(length);
+	public void setLength(final int length) {
+		SwingUtilities.invokeLater(new Runnable() {
+			@Override
+			public void run() {
+				loadProgress.setLength(length);
+			}
+		});
 	}
 	/** Getter for length */
 	public int getLength() {
 		return loadProgress.getLength();
 	}
 	/** Setter for value */
-	public void setValue(int value) {
-		loadProgress.setValue(value);
+	public void setValue(final int value) {
+		SwingUtilities.invokeLater(new Runnable() {
+			@Override
+			public void run() {
+				loadProgress.setValue(value);
+			}
+		});
 	}
 	/** Getter for value */
 	public int getValue() {
 		return loadProgress.getValue();
 	}
-	public void incrValue(int i) {
-		loadProgress.incrValue(i);
+	public void incrValue(final int i) {
+		SwingUtilities.invokeLater(new Runnable() {
+			@Override
+			public void run() {
+				loadProgress.incrValue(i);
+			}
+		});
 	}
 	
+	boolean finished = false;
+	
 	/** Setter for finished */
 	public void setFinished(boolean finished) {
-		loadProgress.setFinished(finished);
+		this.finished = finished;
 	}
 	/** Getter for finished */
 	public boolean getFinished() {
-		return loadProgress.getFinished();
+		return this.finished;
 	}
 	
 	/** Setter for phaseValue */
-	public void setPhaseValue(int phaseValue) {
-		loadProgress.setPhaseValue(phaseValue);
+	public void setPhaseValue(final int phaseValue) {
+		SwingUtilities.invokeLater(new Runnable() {
+			@Override
+			public void run() {
+				loadProgress.setPhaseValue(phaseValue);
+			}
+		});
 	}
 	/** Getter for phaseValue */
 	public int getPhaseValue() {
@@ -140,17 +162,27 @@ public class TVModelLoader2 implements ProgressTrackable {
 	}
 	
 	/** Setter for phaseLength */
-	public void setPhaseLength(int phaseLength) {
-		if (loadProgress != null)
-			loadProgress.setPhaseLength(phaseLength);
+	public void setPhaseLength(final int phaseLength) {
+		SwingUtilities.invokeLater(new Runnable() {
+			@Override
+			public void run() {
+				if (loadProgress != null)
+					loadProgress.setPhaseLength(phaseLength);
+			}
+		});
 	}
 	/** Getter for phaseLength */
 	public int getPhaseLength() {
 		return loadProgress.getPhaseLength();
 	}
 	
-	public void setPhaseText(String phaseText) {
-		loadProgress.setPhaseText(phaseText);
+	public void setPhaseText(final String phaseText) {
+		SwingUtilities.invokeLater(new Runnable() {
+			@Override
+			public void run() {
+				loadProgress.setPhaseText(phaseText);
+			}
+		});
 	}
 	/** Getter for phaseText */
 	public String getPhaseText() {
@@ -179,7 +211,9 @@ public class TVModelLoader2 implements ProgressTrackable {
 		// this method is invoked every few hundred ms
 		public void actionPerformed(ActionEvent evt) {
 			if (getCanceled() || getFinished()) {
-				setFinished(true);
+				if (getFinished()) {
+					loadProgress.setFinished(true);
+				}
 				loadTimer.stop();
 				if (getHadProblem() == false) { 
 					loadProgress.setVisible(false);
@@ -208,11 +242,12 @@ public class TVModelLoader2 implements ProgressTrackable {
 		worker.start();
 		loadTimer = new javax.swing.Timer(200, new TimerListener());
 		loadTimer.start();
+		
 		// show a modal dialog, should block until loading done...
 		loadProgress.setIndeterminate(true);
 		((LoadProgress2) loadProgress).pack();
-		loadProgress.setVisible(true);
-		
+		loadProgress.setVisible(true);				
+
 		// but just in case it doesn't, we'll join on the worker
 		try {
 			worker.join();
